==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/fr.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', [
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Panneau d\'activité',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Cliquer pour ouvrir le panneau d\'activité',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Nouvelle entrée de journal',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Fermer',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Charger toutes les entrées',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Charger les entrées précédentes',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'En cliquant sur le bouton "Envoyer", vous allez enregistrer en une seule fois toutes les entrées de journaux mises à jour.',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Enregistrement de plusieurs journaux',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Temps calme, il n\'y a pas encore d\'activité',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Cliquer pour ouvrir l\'onglet de notification et obtenir plus d\'informations',
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Déplier',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Replier',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Activité',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Brouillon',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Fermer toutes les entrées',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Ouvrir toutes les entrées',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Modif.',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Afficher / masquer les modifications sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Choisir les journaux à afficher sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Journaux',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Afficher / masquer les entrées de journaux sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Statuts',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Afficher / masquer les changements de statut sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Nombre de personnes ayant contribué aux entrées affichées',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Nombre de messages dans le(s) journal / journaux affichés',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/layouts/activity-panel/fr.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Déplier',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Replier',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Fermer',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Charger les entrées précédentes',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Charger toutes les entrées',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Activité',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Brouillon',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Journaux',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Afficher / masquer les entrées de journaux sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Choisir les journaux à afficher sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Statuts',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Afficher / masquer les changements de statut sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Modif.',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Afficher / masquer les modifications sur cet onglet',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Ouvrir toutes les entrées',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Fermer toutes les entrées',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Nombre de personnes ayant contribué aux entrées affichées',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Nombre de messages dans le(s) journal / journaux affichés',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Nouvelle entrée de journal',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Enregistrement de plusieurs journaux',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'En cliquant sur le bouton "Envoyer", vous allez enregistrer en une seule fois toutes les entrées de journaux mises à jour.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Cliquer pour ouvrir l\'onglet de notification et obtenir plus d\'informations',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Temps calme, il n\'y a pas encore d\'activité',
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Panneau d\'activité',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Cliquer pour ouvrir le panneau d\'activité',
));
